@@ -25,6 +25,7 @@ __all__ = [
     'mapping',
     'megares_data_finder',
     'megares_zip_parser',
+    'mic_plotter',
     'mlst_profile',
     'mlst_reporter',
     'pubmlst_getter',
@@ -38,6 +39,7 @@ __all__ = [
     'ref_seq_chooser',
     'report',
     'report_filter',
+    'report_flag_expander',
     'scaffold_graph',
     'samtools_variants',
     'sequence_metadata',
