@@ -1,7 +1,9 @@
 __all__ = [
     'aln2meta',
+    'expandflag',
     'flag',
     'getref',
+    'micplot',
     'prepareref',
     'pubmlstget',
     'pubmlstspecies',
